summaryrefslogtreecommitdiff
path: root/tests/model_fields
diff options
context:
space:
mode:
Diffstat (limited to 'tests/model_fields')
-rw-r--r--tests/model_fields/models.py12
1 files changed, 11 insertions, 1 deletions
diff --git a/tests/model_fields/models.py b/tests/model_fields/models.py
index 8a6e9c83b1..0222f9a3df 100644
--- a/tests/model_fields/models.py
+++ b/tests/model_fields/models.py
@@ -145,12 +145,22 @@ class VerboseNameField(models.Model):
field22 = models.URLField("verbose field22")
-# This model isn't used in any test, just here to ensure it validates successfully.
+###############################################################################
+# These models aren't used in any test, just here to ensure they validate
+# successfully.
+
# See ticket #16570.
class DecimalLessThanOne(models.Model):
d = models.DecimalField(max_digits=3, decimal_places=3)
+# See ticket #18389.
+class FieldClassAttributeModel(models.Model):
+ field_class = models.CharField
+
+###############################################################################
+
+
class DataModel(models.Model):
short_data = models.BinaryField(max_length=10, default=b'\x08')
data = models.BinaryField()